@@ -41,21 +41,11 @@ class SqlDialects(object):
 
     def sqlrepr(self, dialect, cls):
         ns = self._registry.setdefault(dialect, {})
-
-        # Looking for registered dialect
-        callback = ns.get(cls, None)
-        if callback is not None:
-            return callback
-
-        # Looking for __sqlrepr__ directly in class, except parent classes
-        if '__sqlrepr__' in cls.__dict__:
-            return getattr(cls, '__sqlrepr__')
-
-        # Looking for parents
-        for parent in cls.__bases__:
-            callback = self.sqlrepr(dialect, parent)
-            if callback is not None:
-                return callback
+        for t in cls.mro():
+            if t in ns:  # Looking for registered dialect
+                return ns[t]
+            elif '__sqlrepr__' in t.__dict__:  # Looking for __sqlrepr__ directly in class, except parent classes
+                return t.__sqlrepr__
         return None
 
 sql_dialects = SqlDialects()
@@ -230,6 +220,12 @@ class Comparable(object):
     def count(self):
         return Constant("COUNT")(self)
 
+    def asc(self):
+        return Suffix(self, "ASC")
+
+    def desc(self):
+        return Suffix(self, "DESC")
+
     def __getitem__(self, key):
         """Returns self.between()"""
         if isinstance(key, slice):
@@ -443,6 +439,21 @@ class Prefix(Expr):
         return sqlparams(self._expr)
 
 
+class Suffix(Expr):
+
+    __slots__ = ('_suffix', '_expr', )
+
+    def __init__(self, expr, suffix):
+        self._suffix = suffix
+        self._expr = prepare_expr(expr)
+
+    def __sqlrepr__(self, dialect):
+        return "{0} {1}".format(sqlrepr(self._expr, dialect), self._suffix)
+
+    def __params__(self):
+        return sqlparams(self._expr)
+
+
 class Between(Expr):
 
     __slots__ = ('_expr', '_start', '_end')
@@ -558,6 +569,7 @@ class Alias(Expr):
     def __sqlrepr__(self, dialect):
         return qn(self._sql, dialect)
 
+
 class Index(Alias):
     pass
 
@@ -909,8 +921,6 @@ class QuerySet(Expr):
                 for i, f in enumerate(args):
                     if not isinstance(f, Expr):
                         f = Field(f)
-                    if isinstance(f, Alias):
-                        f = ExprList(f.expr, Constant("AS"), f).join(" ")
                     args[i] = f
                 self._fields.extend(args)
             return self
@@ -974,7 +984,7 @@ class QuerySet(Expr):
 
     @opt_checker(["desc", "reset", ])
     def order_by(self, *args, **opts):
-        direct = Constant("DESC") if opts.get("desc") else Constant("ASC")
+        direct = "DESC" if opts.get("desc") else "ASC"
         if opts.get("reset"):
             self = self.clone()
             self._order_by.reset()
@@ -987,7 +997,9 @@ class QuerySet(Expr):
                 self = self.order_by(*args.pop(0), reset=True)
             if len(args):
                 for f in args:
-                    self._order_by.append(ExprList(f, direct).join(" "))
+                    if not (isinstance(f, Suffix) and f._suffix in ("ASC", "DESC")):
+                        f = Suffix(f, direct)
+                    self._order_by.append(f)
             return self
         return self._order_by
 
@@ -1122,7 +1134,12 @@ class QuerySet(Expr):
 
     def _sql_extend(self, sql, parts):
         if "fields" in parts and self._fields:
-            sql.append(self._fields)
+            fields = ExprList().join(", ")
+            for f in self._fields:
+                if isinstance(f, Alias):
+                    f = ExprList(f.expr, Constant("AS"), f).join(" ")
+                fields.append(f)
+            sql.append(fields)
         if "tables" in parts and self._tables:
             sql.append(self._tables)
         if "from" in parts and self._tables:
